@@ -4,6 +4,9 @@ import numpy as np
 
 from pandas_ta_quant import pd
 
+print('NUMPY VERSION', np.__version__)
+
+
 DF_TEST_MULTI = pd.read_pickle(os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "spy_gld.pickle"))
 DF_TEST = pd.read_csv(os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "SPY.csv"), index_col='Date', parse_dates=True)
 DF_TEST2 = pd.read_csv(os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "GLD.csv"), index_col='Date', parse_dates=True)
@@ -12,4 +15,7 @@ DF_TEST_MULTI_ROW_MULTI_COLUMN = pd.concat([DF_TEST_MULTI.add_multi_index("A", a
 DF_DEBUG = pd.DataFrame({"Close": np.random.random(10)})
 
 DF_INVERSE_GAF = pd.read_pickle(os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "inverse_gaf.df"))
-DF_TEST_MULTI_CLASS = pd.read_pickle(os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "one_hot_classified_df.pickle"))
\ No newline at end of file
+DF_TEST_MULTI_CLASS = pd.read_pickle(os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "one_hot_classified_df.pickle"))
+
+CSV_TRADES = os.path.join(os.path.dirname(os.path.abspath(__file__)), ".data", "trades.csv")
+
