@@ -1,6 +1,6 @@
 from unittest import TestCase
 
-from pandas_ta_quant.technical_analysis import ta_gkyz_volatility, ta_cc_volatility
+from pandas_ta_quant.technical_analysis import ta_gkyz_volatility, ta_cc_volatility, ta_repeat
 from pandas_ta_quant_test.config import DF_TEST
 
 
@@ -13,7 +13,7 @@ class TestMeta(TestCase):
             return (ta_gkyz_volatility(df, period=param) / ta_cc_volatility(df["Close"], period=param) - 1)\
                 .rename(f"{param}")
 
-        result = df.ta.repeat(test, range(2, 10), multiindex="HF/RF Vola Ratio").dropna()
+        result = ta_repeat(df, test, range(2, 10), multiindex="HF/RF Vola Ratio").dropna()
         #print(result)
 
         self.assertEqual(result.shape, (91, 8))
